@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2016 NVIDIA Corporation
+    Copyright (c) 2016-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -68,9 +68,23 @@ typedef struct
         NvU64 handling_ref_count;
     };
 
-    // Number of the bottom-half invocations for this interrupt on a GPU over
-    // its lifetime
-    NvU64 bottom_half_count;
+    struct
+    {
+        // Number of the bottom-half invocations for this interrupt on a GPU over
+        // its lifetime
+        NvU64 bottom_half_count;
+
+        // A bitmask of the CPUs on which the bottom half has executed. The
+        // corresponding bit gets set once the bottom half executes on that
+        // CPU.
+        // This mask is useful when testing that the bottom half is getting
+        // executed on the correct set of CPUs.
+        struct cpumask cpus_used_mask;
+
+        // An array (one per possible CPU), which holds the number of times the
+        // bottom half has executed on that CPU.
+        NvU64 *cpu_exec_count;
+    } stats;
 
     // This is the number of times the function that disables this type of
     // interrupt has been called without a corresponding call to the function
@@ -114,7 +128,7 @@ typedef struct
 } uvm_isr_info_t;
 
 // Entry point for interrupt handling. This is called from RM's top half
-NV_STATUS uvm8_isr_top_half(const NvProcessorUuid *gpu_uuid);
+NV_STATUS uvm8_isr_top_half_entry(const NvProcessorUuid *gpu_uuid);
 
 // Initialize ISR handling state
 NV_STATUS uvm_gpu_init_isr(uvm_gpu_t *gpu);
