@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -421,7 +421,7 @@ struct uvm_va_block_struct
     //       anyway. Consider using a dense array of just the GPUs registered in
     //       this VA space, depending on the perf of accessing that array and on
     //       how noticeable this memory overhead actually is.
-    uvm_va_block_gpu_state_t *gpus[UVM_MAX_GPUS];
+    uvm_va_block_gpu_state_t *gpus[UVM_ID_MAX_GPUS];
 
     // Mask to keep track of the pages that are read-duplicate
     uvm_page_mask_t read_duplicated_pages;
@@ -719,7 +719,7 @@ NV_STATUS uvm_va_block_map_mask(uvm_va_block_t *va_block,
 // within the region. If the page mask is NULL then the whole region is
 // unmapped.
 //
-// If id is UVM_CPU_ID, this is guaranteed to return NV_OK, and this is safe to
+// If id is UVM_ID_CPU, this is guaranteed to return NV_OK, and this is safe to
 // call without holding a reference on the mm which owns the associated vma.
 //
 // Any CPU unmappings will wait for the va_block tracker. If this function
@@ -801,7 +801,7 @@ NV_STATUS uvm_va_block_unset_read_duplication(uvm_va_block_t *va_block,
 // prot_to_revoke must be greater than UVM_PROT_READ_ONLY. Caller should call
 // unmap explicitly if it wants to revoke all access privileges.
 //
-// If id is UVM_CPU_ID, and prot_to_revoke is UVM_PROT_READ_WRITE_ATOMIC, no
+// If id is UVM_ID_CPU, and prot_to_revoke is UVM_PROT_READ_WRITE_ATOMIC, no
 // action is performed. If the processor id corresponds to the CPU and vma->mm
 // is different than current->mm, the page will be simply unmapped. Caller
 // should call unmap explicitly if it wants to revoke all access privileges.
@@ -980,7 +980,8 @@ NV_STATUS uvm_va_block_cpu_fault(uvm_va_block_t *va_block,
 //
 // Locking:
 //  - vma->vm_mm->mmap_sem must be held in at least read mode. Note, that might
-//    not be the same as current->mm->mmap_sem. (only if processor_id == UVM_CPU_ID)
+//    not be the same as current->mm->mmap_sem. (only if
+//    UVM_ID_IS_CPU(processor_id))
 //  - va_space lock must be held in at least read mode
 //  - va_block lock must be held
 //
@@ -1717,7 +1718,7 @@ static NvU32 uvm_va_block_page_size_processor(uvm_va_block_t *va_block,
                                               uvm_processor_id_t processor_id,
                                               uvm_page_index_t page_index)
 {
-    if (processor_id == UVM_CPU_ID)
+    if (UVM_ID_IS_CPU(processor_id))
         return uvm_va_block_page_size_cpu(va_block, page_index);
     else
         return uvm_va_block_page_size_gpu(va_block, processor_id, page_index);
