@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2016-2018 NVIDIA Corporation
+    Copyright (c) 2016-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -39,7 +39,7 @@ void uvm_hal_volta_arch_init_properties(uvm_gpu_t *gpu)
 
     gpu->utlb_per_gpc_count = uvm_volta_get_utlbs_per_gpc(gpu);
 
-    gpu->fault_buffer_info.replayable.utlb_count = gpu->gpc_count * gpu->utlb_per_gpc_count;
+    gpu->fault_buffer_info.replayable.utlb_count = gpu->rm_info.gpcCount * gpu->utlb_per_gpc_count;
     {
         uvm_fault_buffer_entry_t *dummy;
         UVM_ASSERT(gpu->fault_buffer_info.replayable.utlb_count <= (1 << (sizeof(dummy->fault_source.utlb_id) * 8)));
@@ -67,7 +67,7 @@ void uvm_hal_volta_arch_init_properties(uvm_gpu_t *gpu)
 
     // Pascal and Volta require post-invalidate membars to flush out HSHUB. See
     // bug 1975028. All GV100-class chips supported by UVM have HSHUB.
-    UVM_ASSERT(gpu->architecture == NV2080_CTRL_MC_ARCH_INFO_ARCHITECTURE_GV100);
+    UVM_ASSERT(gpu->rm_info.gpuArch == NV2080_CTRL_MC_ARCH_INFO_ARCHITECTURE_GV100);
     gpu->num_hshub_tlb_invalidate_membars = 2;
 
     // Volta can place GPFIFO in vidmem
