@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2013-2018 NVIDIA Corporation
+    Copyright (c) 2013-2019 NVIDIA Corporation
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -17,35 +17,14 @@
     02110-1301, USA.
 *******************************************************************************/
 
-/*
- * This file contains code that is common to all variants of the (Linux) UVM
- * kernel module.
- */
-
 #include "uvm_common.h"
 #include "uvm_linux.h"
-
-// TODO: Bug 1766109: Remove this when the GPU event stubs are no longer needed
-#include "nv_uvm_interface.h"
-
-#include "uvm8_init.h"
 #include "uvm8_forward_decl.h"
 
 // TODO: Bug 1710855: Tweak this number through benchmarks
 #define UVM_SPIN_LOOP_SCHEDULE_TIMEOUT_NS   (10*1000ULL)
 #define UVM_SPIN_LOOP_PRINT_TIMEOUT_SEC     30ULL
 
-static dev_t g_uvmBaseDev;
-
-static char* uvm_driver_mode = "8";
-
-// There used to be other choices, but now there is only one driver mode: 8.
-// If no more choices show up soon, we may just delete this module parameter
-// entirely.
-module_param(uvm_driver_mode, charp, S_IRUGO);
-MODULE_PARM_DESC(uvm_driver_mode,
-                "Set the uvm kernel driver mode. Choices include: 8");
-
 // Default to debug prints being enabled for debug and develop builds and
 // disabled for release builds.
 static int uvm_debug_prints = UVM_IS_DEBUG() || UVM_IS_DEVELOP();
@@ -60,106 +39,14 @@ bool uvm_debug_prints_enabled()
     return uvm_debug_prints != 0;
 }
 
-typedef enum
-{
-    UVM_DRIVER_MODE_8,
-} UvmDriverMode;
-
-static const char * uvm_driver_mode_to_string(UvmDriverMode uvmDriverMode)
-{
-    switch (uvmDriverMode)
-    {
-        case UVM_DRIVER_MODE_8:
-            return "8";
-    }
-    return "invalid";
-}
-
-static UvmDriverMode uvm_get_mode(void)
-{
-    static NvBool bUvmDriverModeChecked = NV_FALSE;
-    static UvmDriverMode uvmDriverMode;
-
-    if (!bUvmDriverModeChecked)
-    {
-        uvmDriverMode = UVM_DRIVER_MODE_8;
-
-        bUvmDriverModeChecked = NV_TRUE;
-    }
-
-    return uvmDriverMode;
-}
-
-NV_STATUS uvm_api_initialize(UVM_INITIALIZE_PARAMS *params, struct file *filp)
-{
-    params->rmStatus = uvm8_initialize(params, filp);
-    return params->rmStatus;
-}
-
-// This function serves to 'stub' out functionality by being a No-Op and
-// returning NV_OK early.
-NV_STATUS uvm_api_stub(void *pParams, struct file *filp)
-{
-    return NV_OK;
-}
-
-// This function serves to identify functionality that isn't supported
-// in this UVM driver, by returning NV_ERR_NOT_SUPPORTED early.
-NV_STATUS uvm_api_unsupported(void *pParams, struct file *filp)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
-//
-// TODO: Bug 1766109: uvm8: delete UVM-Lite files and remove -lite mode
-//  ...just remove -lite mode, instead of the original to-do: which was:
-//
-static int __init uvm_init(void)
-{
-    NvBool allocated_dev = NV_FALSE;
-
-    // The various helper init routines will create their own minor devices, so
-    // we only need to create space for them here.
-    int ret = alloc_chrdev_region(&g_uvmBaseDev,
-                              0,
-                              NVIDIA_UVM_NUM_MINOR_DEVICES,
-                              NVIDIA_UVM_DEVICE_NAME);
-    if (ret != 0) {
-        UVM_ERR_PRINT("alloc_chrdev_region failed: %d\n", ret);
-        goto error;
-    }
-    allocated_dev = NV_TRUE;
-
-    ret = uvm8_init(g_uvmBaseDev);
-
-    if (ret != 0) {
-        UVM_ERR_PRINT("uvm init failed: %d\n", ret);
-        goto error;
-    }
-
-    pr_info("Loaded the UVM driver in %s mode, major device number %d\n",
-            uvm_driver_mode_to_string(uvm_get_mode()), MAJOR(g_uvmBaseDev));
-
-    if (uvm_enable_builtin_tests)
-        pr_info("Built-in UVM tests are enabled. This is a security risk.\n");
-
-    return 0;
-
-error:
-    if (allocated_dev)
-        unregister_chrdev_region(g_uvmBaseDev, NVIDIA_UVM_NUM_MINOR_DEVICES);
-
-    return ret;
-}
-
-static void __exit uvm_exit(void)
-{
-    uvm8_exit();
-
-    unregister_chrdev_region(g_uvmBaseDev, NVIDIA_UVM_NUM_MINOR_DEVICES);
-
-    pr_info("Unloaded the UVM driver in %s mode\n", uvm_driver_mode_to_string(uvm_get_mode()));
-}
+// This parameter allows a program in user mode to call the kernel tests
+// defined in this module. This parameter should only be used for testing and
+// must not be set to true otherwise since it breaks security when it is
+// enabled. By default and for safety reasons this parameter is set to false.
+int uvm_enable_builtin_tests __read_mostly = 0;
+module_param(uvm_enable_builtin_tests, int, S_IRUGO);
+MODULE_PARM_DESC(uvm_enable_builtin_tests,
+                 "Enable the UVM built-in tests. (This is a security risk)");
 
 //
 // Convert kernel errno codes to corresponding NV_STATUS
@@ -294,20 +181,16 @@ int nv_status_to_errno(NV_STATUS status)
 
 //
 // This routine retrieves the process ID of current, but makes no attempt to
-// refcount or lock the pid in place, because that capability is only available
-// to GPL-licenses device drivers.
-//
-// TODO: Bug 1483843: Use the GPL-protected routines if and when we are able to
-// change over to a dual MIT/GPL license.
+// refcount or lock the pid in place.
 //
 unsigned uvm_get_stale_process_id(void)
 {
-    return (unsigned) current->tgid;
+    return (unsigned)task_tgid_vnr(current);
 }
 
 unsigned uvm_get_stale_thread_id(void)
 {
-    return (unsigned) current->pid;
+    return (unsigned)task_pid_vnr(current);
 }
 
 //
@@ -362,17 +245,3 @@ NV_STATUS uvm_spin_loop(uvm_spin_loop_t *spin)
     return NV_OK;
 }
 
-module_init(uvm_init);
-module_exit(uvm_exit);
-
-// This parameter allows a program in user mode to call the kernel tests
-// defined in this module. This parameter should only be used for testing and
-// must not be set to true otherwise since it breaks security when it is
-// enabled. By default and for safety reasons this parameter is set to false.
-int uvm_enable_builtin_tests = 0;
-module_param(uvm_enable_builtin_tests, int, S_IRUGO);
-MODULE_PARM_DESC(uvm_enable_builtin_tests,
-                 "Enable the UVM built-in tests. (This is a security risk)");
-
-MODULE_LICENSE("Dual MIT/GPL");
-MODULE_INFO(supported, "external");
